@@ -8,6 +8,10 @@ S3Config = TypedDict('S3Config', {
     "model_download_bucket": str,
     "model_download_path": List[str],
 })
+URIPrefix = TypedDict('URIPrefix', {
+    "connector": str,
+    "address": str,
+})
 DagDef = TypedDict('DagDef', {
     "company": str,
     "default_input_key": Optional[str],
@@ -16,8 +20,20 @@ DagDef = TypedDict('DagDef', {
     "name": str,
     "nodes": List['NodeDef'],
     "queue_mng": Optional[str],
-    "state": str,
+    "uri_prefix": URIPrefix,
+    "state_uri": str,
 })
+UserDagDef = TypedDict('UserDagDef', {
+    "company": str,
+    "default_input_key": Optional[str],
+    "default_output_key": Optional[str],
+    "high_priority": bool,
+    "name": str,
+    "nodes": List['NodeDef'],
+    "queue_mng": Optional[str],
+    "uri_prefix": URIPrefix,
+    "state_uri": str,
+}, total=False)
 NodeDef = TypedDict('NodeDef', {
     "blobs": Dict[str, str],
     "id": str,
@@ -51,6 +67,7 @@ SettingsObj = TypedDict('SettingsObj', {
     "triton": Dict[str, S3BucketSettings],
     "es": Dict[str, ESConnectorSettings],
     "dremio": Dict[str, DremioAuthSettings],
+    "versions": Dict[str, Tuple[str, str]],
 }, total=False)
 TaskType = Literal[
     "node:cpubig",
@@ -207,7 +224,8 @@ DagInfo = TypedDict('DagInfo', {
     "nodes": List[NodeInfo],
     "outs": List[Tuple[str, str]],
     "queue_mng": Optional[str],
-    "state": str,
+    "uri_prefix": URIPrefix,
+    "state_uri": str,
 })
 BlobInit = TypedDict('BlobInit', {
     "blob": str,
